;; TODO
;; *  global variable "peaks" could maybe be left out..


breed [ climbers climber ]
breed [ followers follower ]
breed [ mavericks maverick ]
breed [ foliators foliator ]
breed [ particles particle ]
breed [ markers marker ]

patches-own [ 
  significance
  times-visited
]

turtles-own [
  previous-significance
  at-peak?
]

markers-own [
  by-follower? ;; these variables are used to track which agent type has left the marker. Only need to measure that when interested
  by-maverick?
]

globals [
  peaks  ;; this is the patch-set that has all the peaks
  peaks-list ;; This is an ordered tuple of patches. This list is necessary because the patch-set itself is not ordered. 
  peaks-first-visited
  peaks-times-visited ;; these three lists are needed in order to track when which peak patch has been visited first and how often in total
  sig-progress-200  
  sig-progress-500
  sig-progress-1000
  sig-progress-2000
  total-progress-200
  total-progress-500
  total-progress-1000
  total-progress-2000  ;; these variables store epistemic progress in specific cycles
  progress-before
  inertia? ;; this variable to abort simulation in case nothing happens anymore
]

to setup
  clear-all
  reset-ticks
  
  ;; create gaussian hills
  ask patches [
    let x pxcor
    let y pycor
    let sig 0.75 * (exp (-0.02 * (-25 + x) ^ 2 - 0.01 * (-25 + x) * (-25 + y) - 0.02 * (-25 + y) ^ 2))
    set significance sig
    set sig 0.7 * (exp (-0.01 * (5 + x) ^ 2 - 0.01 * (5 + x) * (5 + y) - 0.01 * (5 + y) ^ 2))
    set significance (significance + sig)
    set pcolor scale-color green significance 0 0.75
    set times-visited 0
  ]
 
  
    ;; truncate gaussian hills
  if truncated-gaussian? [
    ask patches with [significance < cutoff-threshold] [
    set significance 0 
    ]
  ]
   
 
  ;; initialise the list to count the visits to the peaks
  set peaks patches with [is-peak?]
 ; ask peaks [ set peaks (patch-set peaks neighbors4)] ;; you can include the neighbors of the peaks in peaks patch-set
  
  set peaks-list sort-on [pxcor] peaks
  set peaks-first-visited (list )
  set peaks-times-visited (list )
  foreach peaks-list [
    set peaks-first-visited lput -1 peaks-first-visited 
    set peaks-times-visited lput 0 peaks-times-visited]
  
  ;; initialise statistics variables with -1
  set sig-progress-200 -1  
  set sig-progress-500 -1
  set sig-progress-1000 -1
  set sig-progress-2000 -1
  set total-progress-200 -1
  set total-progress-500 -1
  set total-progress-1000 -1
  set total-progress-2000 -1
  set progress-before -1
  set inertia? false
  
  
  ;; create agents
  ;; create foliators
  ask n-of number-of-foliators patches with [significance < cutoff-threshold] [
    sprout-foliators 1 [ 
      set color blue
      set heading (360 * ln (random-float 360)) mod 360
    ] 
  ]
  
  ;; create climbers
  ask n-of number-of-climbers patches with [significance < cutoff-threshold] [
    sprout-climbers 1 [ set color white ]
  ]
  
  ;; create mavericks and followers
  ask n-of round number-of-mavericks patches with [significance < cutoff-threshold] [
    sprout-mavericks 1 [ set color yellow ]
  ]
  
  ask n-of round number-of-followers patches with [significance < cutoff-threshold] [
    sprout-followers 1 [ set color pink ]
  ]
  
  ;; create particles
  let number-of-swarms 3 + number-of-particles / 10
  let particles-per-swarm number-of-particles / number-of-swarms
  let modulo-particles number-of-particles mod number-of-swarms
  let swarm-radius sqrt particles-per-swarm * ( zor )
  repeat number-of-swarms [ 
    let swarm-patches patch-set [patches in-radius swarm-radius] of one-of patches with [significance < cutoff-threshold]
    let random-heading random 360
    ask n-of particles-per-swarm swarm-patches [ sprout-particles 1 ]
    if modulo-particles > 0 [
      ask one-of swarm-patches with [not any? particles-here] [ sprout-particles 1 ]
      set modulo-particles modulo-particles - 1
      ]
    ask particles-on swarm-patches [
      set color red  
      set heading random-heading
    ]
  ]
       
  set-default-shape markers "square"
  ask turtles [
    set size 2
    set previous-significance [significance] of patch-here
    set at-peak? false
  ]
  
end


to step
  
  ;; run commands for each agent-type
  ask foliators [
    leave-marker "foliator"
    if (not at-peak?) [ fd 1 ]  
  ]
  
  ask climbers [
    if (he-rule = "Original") [ do-he-rule ]
    if (he-rule = "Rule 2") [ do-he-rule-2 ]
    if (he-rule = "Rule 3") [ do-he-rule-3 ]
    if (he-rule = "Analytically tractable") [ do-he-rule-4 ]
  ]
  
  ask followers [
    if (follow-rule = "Rule 1") [ do-follow-rule ]
    if (follow-rule = "Rule 2") [ do-follow-rule-2 ]
  ]
  
  ask mavericks [
    do-maverick-rule
  ]
  
  ask particles [
    do-particle-rule
  ]
 
 
 ;;
 ;; Statistics
 ;;
 
 ;; check if peak patches have been visited
 foreach peaks-list [
   let pos position ? peaks-list
   ask ? [
     if (times-visited >= 1 and item pos peaks-first-visited = -1) [ set peaks-first-visited replace-item pos peaks-first-visited ticks ] 
     set peaks-times-visited replace-item pos peaks-times-visited times-visited]
 ]
 
 ;; sample epistemic progress
 if ticks = 200 [ 
   set sig-progress-200 count patches with [significance >= cutoff-threshold and times-visited > 0] 
   set total-progress-200 count markers
 ] 
 if ticks = 500 [
   set sig-progress-500 count patches with [significance >= cutoff-threshold and times-visited > 0]
   set total-progress-500 count markers
 ] 
 
   
 if ticks = 1000 [
   set sig-progress-1000 count patches with [significance >= cutoff-threshold and times-visited > 0]
   set total-progress-1000 count markers
 ] 
  
 if ticks = 2000 [
   set sig-progress-2000 count patches with [significance >= cutoff-threshold and times-visited > 0]
   set total-progress-2000 count markers
 ] 
 
 if (ticks mod 500 = 0) [
     if progress-before = count turtles [ set inertia? true ]  
   set progress-before count turtles 
 ]
 if (count markers / count patches = 1) [ set inertia? true ] ;; if the whole landscape is explored

 tick
end

to go
  step
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; search heuristic rules for different agent types, turtle-context
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; The original HE rule
;; This is the rule as it is described in pseudocode in the paper
;; if significance increasing: moves forward two steps
;; if significance the same: moves forward once, and with 2% chance moves forward again with random heading
;; if significance decreasing: moves backward one step, set random heading
to do-he-rule
  leave-marker "climber"
   
  set previous-significance [significance] of patch-here
  fd 1
  ifelse ([significance] of patch-here > previous-significance)
  [
    fd 1
  ]
  [
    ifelse ([significance] of patch-here = previous-significance)
    [
      if (random-float 1.0 < 0.02)
      [
        set heading random 360
        fd 1 
      ]
    ]
    [
      fd -1
      set heading random 360
    ]
  ]
  center-turtle
end

;; The dying in the desert rule
;; this may be the rule that was in fact used in the W&M implementation
;; if significance increasing: moves 1 forward same heading
;; if significance the same: stops 98% of the time, moves forward randomly otherwise
;; if significance decreasing moves forward randomly
to do-he-rule-2
  leave-marker "climber"  
  
  let random-move task
  [
    set previous-significance ([significance] of patch-here)
    set heading random 360
    fd 1 
  ]

  ifelse ([significance] of patch-here > previous-significance)
  [
    set previous-significance ([significance] of patch-here)
    fd 1
  ]
  [
    ifelse ([significance] of patch-here = previous-significance)
    [
      if (random-float 1.0 < 0.02) [ run random-move ] ;; this is what causes the dying in the desert
    ]
    [ ;; i.e. [significance] of patch-here < previous-significance
      run random-move 
    ]
  ]
  center-turtle
end

;; The improved rule
;; if significance increasing: moves 1 forward same heading
;; if significance the same: moves 1 forward, with same heading in 98%, with random heading in 2%
;; if significance decreasing: moves forward randomly
to do-he-rule-3
  leave-marker "climber"    

  ifelse ([significance] of patch-here > previous-significance)
  [
    set previous-significance ([significance] of patch-here)
    fd 1
  ]
  [
    ifelse ([significance] of patch-here = previous-significance) 
    [
      set previous-significance ([significance] of patch-here)
      if (random-float 1.0 < 0.02) [ set heading random 360 ]
      fd 1 
    ]
    [
      set previous-significance ([significance] of patch-here)
      set heading random 360
      fd 1
    ]
  ]
  center-turtle
end

;; The analytically tractable rule
;; if significance = 0, move to a neighbor at random
;; if significance > 0, climb the gradient
to do-he-rule-4
  leave-marker "climber"    
  ifelse ([significance] of patch-here = 0)
  [
    set previous-significance 0         
    move-to one-of neighbors
  ]
  [
    set previous-significance ([significance] of patch-here)
    uphill significance    
  ]
  center-turtle
end

to do-follow-rule
  ;; this rule has a bug: it gets stuck in case there are visited neighbours and all have the same significance
  leave-marker "follower"
  ifelse any-visited-neighbors?
  [
    let current_sig [significance] of patch-here
    ifelse (any? visited-neighbors with [significance >= current_sig])
    [
       face one-of visited-neighbors with [significance >= current_sig]
       fd 1
    ]
    [
      if any-unvisited-neighbors?
      [
        face one-of unvisited-neighbors
        fd 1
      ]
    ]
  ]
  [ ; no visited patches
    face one-of neighbors
    fd 1
  ]
  center-turtle
end

to do-follow-rule-2
  ;; this rule fixes the bug.
  leave-marker "follower"
  ifelse any-visited-neighbors?
  [
    let current_sig [significance] of patch-here
    ifelse (any? visited-neighbors with [significance > current_sig])
    [
       face one-of visited-neighbors with [significance > current_sig]
       fd 1
    ]
    [
      if any-unvisited-neighbors?
      [
        face one-of unvisited-neighbors
        fd 1
      ]
    ]
  ]
  [ ; no visited patches
    face one-of neighbors
    fd 1
  ]
  center-turtle
end


to do-maverick-rule
  leave-marker "maverick"
  
  ifelse (previous-significance <= [significance] of patch-here)
  [
    set previous-significance ([significance] of patch-here)
    ifelse any-unvisited-neighbors?
    [
      face one-of unvisited-neighbors
      fd 1
    ]
    [ ;; if there are no unvistited neighbors
      if (any? neighbors with [significance > [previous-significance] of myself])
      [
        face one-of neighbors with [significance > [previous-significance] of myself]
        fd 1 
      ]
    ]
  ]
  [ ;; if significance is increasing
    fd -1
    set heading random 360
  ]
  center-turtle
end

to do-particle-rule
  leave-marker "particle"
  set previous-significance ([significance] of patch-here)
  
  ifelse (random-float 1.0 < p-clairvoyance and any? neighbors with [significance > [previous-significance] of myself]) [
    face min-one-of peaks [distance myself]
  ]
  [
    if any? other particles in-radius zoo [ set heading swarm-orientation heading [heading] of other particles in-radius zoo ]
    let closest min-one-of other particles  with [distance myself > 0] in-radius zor [distance myself] 
    if closest != nobody [  ;; if there is an agent in my zor
        let degrees-to-closest subtract-headings (towards closest) heading ;; NOTE: swerve-degree now hard coded, 10 degrees
        if degrees-to-closest < 0 and degrees-to-closest >= -90 [ rt 10 ]  ;; if closest is to the left, turn to the right
        if degrees-to-closest >= 0 and degrees-to-closest <= 90 [ lt 10 ]  ;; if closest is to the right, turn to the left
    ]
  ]
  fd 1
  ;center-turtle ;; deactivated, influences swarm behavior
end


to-report swarm-orientation [me them] ;; "me" is heading of caller turtle, "them" is list of headings of others
  let differences [ ]
  foreach them [ set differences lput (subtract-headings ? me) differences ]
  report me + mean differences
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; methods for view
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to show-perimeter
  ask patches [ 
    if (significance != 0 and any? neighbors with [significance = 0]) [
      set pcolor gray
    ]
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; methods for turtles interaction with patches in neighborhood, turtle-context
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; turtle context
to center-turtle
  if center-turtle? [ setxy pxcor pycor ]
end

to leave-marker [ agent-type ]
  ifelse member? patch-here peaks [ set at-peak? true ] [ set at-peak? false ]
  if not any? markers-here [ ask patch-here [ sprout-markers 1 [ 
        set color [255 255 0 125]  
        set by-maverick? false ; initialize variables that record who has visited it
        set by-follower? false
        ] ] 
  ]
  ask markers-here [
    if agent-type = "maverick" [set by-maverick? true]
    if agent-type = "follower" [set by-follower? true]
  ]
  ask patch-here [
    set times-visited times-visited + 1
  ]
end

to-report any-visited-neighbors?
  report any? neighbors with [any? markers-here]
end

to-report any-unvisited-neighbors?
  report any? neighbors with [not any? markers-here]
end

to-report visited-neighbors
  report neighbors with [any? markers-here]
end

to-report unvisited-neighbors
  report neighbors with [not any? markers-here]
end

;; patch context
to-report is-peak?
    ifelse (all? neighbors [significance < [significance] of myself])
    [ report true ]
    [ report false]
end
@#$#@#$#@
GRAPHICS-WINDOW
360
60
999
720
50
50
6.23
1
10
1
1
1
0
1
1
1
-50
50
-50
50
1
1
1
ticks
30.0

SLIDER
10
240
190
273
number-of-mavericks
number-of-mavericks
0
100
0
1
1
NIL
HORIZONTAL

SLIDER
10
190
190
223
number-of-climbers
number-of-climbers
0
100
0
1
1
NIL
HORIZONTAL

BUTTON
15
60
175
93
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
15
100
90
133
NIL
step
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
95
100
175
133
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
200
190
310
235
he-rule
he-rule
"Original" "Rule 2" "Rule 3" "Analytically tractable"
0

TEXTBOX
20
10
535
35
Epistemic landscapes, optimal search and the division of cognitive labor
14
0.0
1

PLOT
5
465
210
615
count turtles
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"Turtles" 1.0 0 -16777216 true "" "plot count turtles"

SLIDER
185
100
350
133
cutoff-threshold
cutoff-threshold
0
.1
0.01
0.0001
1
NIL
HORIZONTAL

SWITCH
215
140
350
173
center-turtle?
center-turtle?
0
1
-1000

CHOOSER
200
290
292
335
follow-rule
follow-rule
"Rule 1" "Rule 2"
1

CHOOSER
200
240
292
285
maverick-rule
maverick-rule
"Rule 1"
0

SWITCH
185
60
350
93
truncated-gaussian?
truncated-gaussian?
0
1
-1000

SLIDER
10
155
190
188
number-of-foliators
number-of-foliators
0
100
0
1
1
NIL
HORIZONTAL

SLIDER
200
355
292
388
zoo
zoo
0
10
3
0.1
1
NIL
HORIZONTAL

SLIDER
200
395
292
428
zor
zor
0.6
10
1
0.1
1
NIL
HORIZONTAL

SLIDER
10
385
190
418
p-clairvoyance
p-clairvoyance
0
0.1
0.03
0.005
1
NIL
HORIZONTAL

SLIDER
10
315
190
348
number-of-particles
number-of-particles
0
80
0
1
1
NIL
HORIZONTAL

TEXTBOX
200
430
320
471
zoo: zone of orientation\nzor: zone of repulsion
9
0.0
1

TEXTBOX
10
425
205
446
probability to set heading towards peak.
9
0.0
1

MONITOR
10
670
215
715
NIL
peaks-times-visited
1
1
11

MONITOR
10
625
215
670
NIL
peaks-first-visited
17
1
11

MONITOR
220
560
310
605
NIL
count patches with [significance >= cutoff-threshold and times-visited > 0] / count patches with [significance >= cutoff-threshold]
5
1
11

TEXTBOX
220
465
370
483
Explored patches proportion
11
0.0
1

TEXTBOX
220
530
370
556
Explored significant patches proportion
11
0.0
1

SLIDER
10
275
190
308
number-of-followers
number-of-followers
0
400
121
1
1
NIL
HORIZONTAL

MONITOR
250
625
307
670
NIL
inertia?
17
1
11

MONITOR
215
480
315
525
NIL
count patches with [times-visited > 0] / count patches
5
1
11

TEXTBOX
20
35
490
53
Prof. J. McKenzie Alexander, J. Himmelreich, Dr. C. Thompson
11
0.0
1

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -7500403 true true 135 285 195 285 270 90 30 90 105 285
Polygon -7500403 true true 270 90 225 15 180 90
Polygon -7500403 true true 30 90 75 15 120 90
Circle -1 true false 183 138 24
Circle -1 true false 93 138 24

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.5
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Finding peaks: particles" repetitions="600" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="2000"/>
    <exitCondition>not member? -1 peaks-first-visited</exitCondition>
    <metric>count particles</metric>
    <metric>peaks-times-visited</metric>
    <metric>peaks-first-visited</metric>
    <metric>max peaks-first-visited</metric>
    <metric>count markers</metric>
    <metric>count markers / count patches</metric>
    <metric>count patches with [significance &gt;= cutoff-threshold and times-visited &gt; 0] / count patches with [significance &gt;= cutoff-threshold]</metric>
    <enumeratedValueSet variable="truncated-gaussian?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="center-turtle?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cutoff-threshold">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-foliators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-climbers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="he-rule">
      <value value="&quot;Rule 3&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-followers-mavericks">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maverick-rule">
      <value value="&quot;Rule 1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="follow-rule">
      <value value="&quot;Rule 1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-swarms">
      <value value="7"/>
      <value value="8"/>
      <value value="12"/>
      <value value="15"/>
      <value value="18"/>
      <value value="20"/>
      <value value="23"/>
      <value value="25"/>
      <value value="27"/>
      <value value="30"/>
      <value value="35"/>
      <value value="37"/>
      <value value="40"/>
      <value value="45"/>
      <value value="50"/>
      <value value="52"/>
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-particles-per-swarm">
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-clairvoyance">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.02"/>
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="zor">
      <value value="2.5"/>
      <value value="3"/>
      <value value="3.5"/>
      <value value="4"/>
      <value value="4.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="zoo">
      <value value="2.5"/>
      <value value="3"/>
      <value value="3.5"/>
      <value value="4"/>
      <value value="4.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="1A Controls original" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="50000"/>
    <exitCondition>(count patches - count markers &lt; 1) or (all? climbers [distance min-one-of peaks [distance myself] &lt; 2])</exitCondition>
    <metric>ticks</metric>
    <metric>count climbers ;; CHANGE</metric>
    <metric>peaks-times-visited</metric>
    <metric>peaks-first-visited</metric>
    <metric>max peaks-first-visited</metric>
    <metric>sig-progress-200</metric>
    <metric>sig-progress-500</metric>
    <metric>sig-progress-2000</metric>
    <metric>total-progress-200</metric>
    <metric>total-progress-500</metric>
    <metric>total-progress-2000</metric>
    <metric>count markers</metric>
    <metric>count markers / count patches</metric>
    <metric>count patches with [significance &gt;= cutoff-threshold and times-visited &gt; 0] / count patches with [significance &gt;= cutoff-threshold]</metric>
    <metric>count patches with [significance &gt;= cutoff-threshold]</metric>
    <enumeratedValueSet variable="maverick-rule">
      <value value="&quot;Rule 1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="truncated-gaussian?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-followers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="zoo">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cutoff-threshold">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-particles-per-swarm">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="he-rule">
      <value value="&quot;Original&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-swarms">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="follow-rule">
      <value value="&quot;Rule 1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-mavericks">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-foliators">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="number-of-climbers" first="10" step="10" last="400"/>
    <enumeratedValueSet variable="p-clairvoyance">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="zor">
      <value value="6.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="center-turtle?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="1B Controls Rule 2" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="50000"/>
    <exitCondition>(count patches - count markers &lt; 1) or (all? climbers [distance min-one-of peaks [distance myself] &lt; 2])</exitCondition>
    <metric>ticks</metric>
    <metric>count climbers ;; CHANGE</metric>
    <metric>peaks-times-visited</metric>
    <metric>peaks-first-visited</metric>
    <metric>max peaks-first-visited</metric>
    <metric>sig-progress-200</metric>
    <metric>sig-progress-500</metric>
    <metric>sig-progress-2000</metric>
    <metric>total-progress-200</metric>
    <metric>total-progress-500</metric>
    <metric>total-progress-2000</metric>
    <metric>count markers</metric>
    <metric>count markers / count patches</metric>
    <metric>count patches with [significance &gt;= cutoff-threshold and times-visited &gt; 0] / count patches with [significance &gt;= cutoff-threshold]</metric>
    <metric>count patches with [significance &gt;= cutoff-threshold]</metric>
    <enumeratedValueSet variable="maverick-rule">
      <value value="&quot;Rule 1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="truncated-gaussian?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-followers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="zoo">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cutoff-threshold">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-particles-per-swarm">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="he-rule">
      <value value="&quot;Rule 2&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-swarms">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="follow-rule">
      <value value="&quot;Rule 1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-mavericks">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-foliators">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="number-of-climbers" first="10" step="10" last="400"/>
    <enumeratedValueSet variable="p-clairvoyance">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="zor">
      <value value="6.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="center-turtle?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="1C Controls Rule 3" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="50000"/>
    <exitCondition>(count patches - count patches with [times-visited &gt; 0] &lt; 1) or (all? climbers [distance min-one-of peaks [distance myself] &lt; 2])</exitCondition>
    <metric>ticks</metric>
    <metric>count climbers ;; CHANGE</metric>
    <metric>peaks-times-visited</metric>
    <metric>peaks-first-visited</metric>
    <metric>max peaks-first-visited</metric>
    <metric>sig-progress-200</metric>
    <metric>sig-progress-500</metric>
    <metric>sig-progress-2000</metric>
    <metric>total-progress-200</metric>
    <metric>total-progress-500</metric>
    <metric>total-progress-2000</metric>
    <metric>count markers</metric>
    <metric>count patches</metric>
    <metric>count patches with [significance &gt;= cutoff-threshold and times-visited &gt; 0]</metric>
    <metric>count patches with [significance &gt;= cutoff-threshold]</metric>
    <enumeratedValueSet variable="maverick-rule">
      <value value="&quot;Rule 1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="truncated-gaussian?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-followers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="zoo">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cutoff-threshold">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-particles-per-swarm">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="he-rule">
      <value value="&quot;Rule 3&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-swarms">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="follow-rule">
      <value value="&quot;Rule 1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-mavericks">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-foliators">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="number-of-climbers" first="10" step="10" last="400"/>
    <enumeratedValueSet variable="p-clairvoyance">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="zor">
      <value value="6.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="center-turtle?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="1D Mavericks" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="50000"/>
    <exitCondition>inertia?</exitCondition>
    <metric>ticks</metric>
    <metric>count mavericks ;; CHANGE</metric>
    <metric>peaks-times-visited</metric>
    <metric>peaks-first-visited</metric>
    <metric>max peaks-first-visited</metric>
    <metric>sig-progress-200</metric>
    <metric>sig-progress-500</metric>
    <metric>sig-progress-2000</metric>
    <metric>total-progress-200</metric>
    <metric>total-progress-500</metric>
    <metric>total-progress-2000</metric>
    <metric>count markers</metric>
    <metric>count patches</metric>
    <metric>count patches with [significance &gt;= cutoff-threshold and times-visited &gt; 0]</metric>
    <metric>count patches with [significance &gt;= cutoff-threshold]</metric>
    <enumeratedValueSet variable="maverick-rule">
      <value value="&quot;Rule 1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="truncated-gaussian?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-followers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="zoo">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cutoff-threshold">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-particles-per-swarm">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="he-rule">
      <value value="&quot;Rule 3&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-swarms">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="follow-rule">
      <value value="&quot;Rule 1&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="number-of-mavericks" first="10" step="10" last="400"/>
    <enumeratedValueSet variable="number-of-foliators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-climbers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-clairvoyance">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="zor">
      <value value="6.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="center-turtle?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="1E Followers" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="50000"/>
    <exitCondition>inertia?</exitCondition>
    <metric>ticks</metric>
    <metric>count followers ;; CHANGE</metric>
    <metric>peaks-times-visited</metric>
    <metric>peaks-first-visited</metric>
    <metric>max peaks-first-visited</metric>
    <metric>sig-progress-200</metric>
    <metric>sig-progress-500</metric>
    <metric>sig-progress-2000</metric>
    <metric>total-progress-200</metric>
    <metric>total-progress-500</metric>
    <metric>total-progress-2000</metric>
    <metric>count markers</metric>
    <metric>count patches</metric>
    <metric>count patches with [significance &gt;= cutoff-threshold and times-visited &gt; 0]</metric>
    <metric>count patches with [significance &gt;= cutoff-threshold]</metric>
    <enumeratedValueSet variable="maverick-rule">
      <value value="&quot;Rule 1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="truncated-gaussian?">
      <value value="true"/>
    </enumeratedValueSet>
    <steppedValueSet variable="number-of-followers" first="10" step="10" last="400"/>
    <enumeratedValueSet variable="zoo">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cutoff-threshold">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-particles-per-swarm">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="he-rule">
      <value value="&quot;Rule 3&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-swarms">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="follow-rule">
      <value value="&quot;Rule 1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-mavericks">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-foliators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-climbers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-clairvoyance">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="zor">
      <value value="6.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="center-turtle?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="1H Analytically tractable climber" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="50000"/>
    <exitCondition>all? climbers [distance min-one-of peaks [distance myself] &lt; 2]</exitCondition>
    <metric>ticks</metric>
    <metric>count climbers ;; CHANGE</metric>
    <metric>peaks-times-visited</metric>
    <metric>peaks-first-visited</metric>
    <metric>max peaks-first-visited</metric>
    <metric>sig-progress-200</metric>
    <metric>sig-progress-500</metric>
    <metric>sig-progress-1000</metric>
    <metric>sig-progress-2000</metric>
    <metric>total-progress-200</metric>
    <metric>total-progress-500</metric>
    <metric>total-progress-1000</metric>
    <metric>total-progress-2000</metric>
    <metric>count markers</metric>
    <metric>count patches</metric>
    <metric>count patches with [significance &gt;= cutoff-threshold and times-visited &gt; 0]</metric>
    <metric>count patches with [significance &gt;= cutoff-threshold]</metric>
    <enumeratedValueSet variable="maverick-rule">
      <value value="&quot;Rule 1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="truncated-gaussian?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-followers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="zoo">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cutoff-threshold">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-particles-per-swarm">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="he-rule">
      <value value="&quot;Analytically tractable&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-swarms">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="follow-rule">
      <value value="&quot;Rule 1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-mavericks">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-foliators">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="number-of-climbers" first="10" step="10" last="400"/>
    <enumeratedValueSet variable="p-clairvoyance">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="zor">
      <value value="6.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="center-turtle?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="1F Swarm" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="50000"/>
    <exitCondition>inertia?</exitCondition>
    <metric>count particles ;; CHANGE</metric>
    <metric>peaks-times-visited</metric>
    <metric>peaks-first-visited</metric>
    <metric>max peaks-first-visited</metric>
    <metric>sig-progress-200</metric>
    <metric>sig-progress-500</metric>
    <metric>sig-progress-1000</metric>
    <metric>sig-progress-2000</metric>
    <metric>total-progress-200</metric>
    <metric>total-progress-500</metric>
    <metric>total-progress-1000</metric>
    <metric>total-progress-2000</metric>
    <metric>count markers</metric>
    <metric>count patches</metric>
    <metric>count patches with [significance &gt;= cutoff-threshold and times-visited &gt; 0]</metric>
    <metric>count patches with [significance &gt;= cutoff-threshold]</metric>
    <enumeratedValueSet variable="maverick-rule">
      <value value="&quot;Rule 1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="truncated-gaussian?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-followers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="zoo">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cutoff-threshold">
      <value value="0.01"/>
    </enumeratedValueSet>
    <steppedValueSet variable="number-of-particles" first="10" step="10" last="400"/>
    <enumeratedValueSet variable="he-rule">
      <value value="&quot;Rule 3&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="follow-rule">
      <value value="&quot;Rule 1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-mavericks">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-foliators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-climbers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-clairvoyance">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="zor">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="center-turtle?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="1G Anti-Swarm" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="50000"/>
    <exitCondition>inertia?</exitCondition>
    <metric>count particles ;; CHANGE</metric>
    <metric>peaks-times-visited</metric>
    <metric>peaks-first-visited</metric>
    <metric>max peaks-first-visited</metric>
    <metric>sig-progress-200</metric>
    <metric>sig-progress-500</metric>
    <metric>sig-progress-1000</metric>
    <metric>sig-progress-2000</metric>
    <metric>total-progress-200</metric>
    <metric>total-progress-500</metric>
    <metric>total-progress-1000</metric>
    <metric>total-progress-2000</metric>
    <metric>count markers</metric>
    <metric>count patches</metric>
    <metric>count patches with [significance &gt;= cutoff-threshold and times-visited &gt; 0]</metric>
    <metric>count patches with [significance &gt;= cutoff-threshold]</metric>
    <enumeratedValueSet variable="maverick-rule">
      <value value="&quot;Rule 1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="truncated-gaussian?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-followers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="zoo">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cutoff-threshold">
      <value value="0.01"/>
    </enumeratedValueSet>
    <steppedValueSet variable="number-of-particles" first="10" step="10" last="400"/>
    <enumeratedValueSet variable="he-rule">
      <value value="&quot;Rule 3&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="follow-rule">
      <value value="&quot;Rule 1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-mavericks">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-foliators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-climbers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-clairvoyance">
      <value value="0.015"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="zor">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="center-turtle?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="1I Foliator" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="50000"/>
    <exitCondition>inertia?</exitCondition>
    <metric>ticks</metric>
    <metric>count climbers ;; CHANGE</metric>
    <metric>peaks-times-visited</metric>
    <metric>peaks-first-visited</metric>
    <metric>max peaks-first-visited</metric>
    <metric>sig-progress-200</metric>
    <metric>sig-progress-500</metric>
    <metric>sig-progress-1000</metric>
    <metric>sig-progress-2000</metric>
    <metric>total-progress-200</metric>
    <metric>total-progress-500</metric>
    <metric>total-progress-1000</metric>
    <metric>total-progress-2000</metric>
    <metric>count markers</metric>
    <metric>count patches</metric>
    <metric>count patches with [significance &gt;= cutoff-threshold and times-visited &gt; 0]</metric>
    <metric>count patches with [significance &gt;= cutoff-threshold]</metric>
    <enumeratedValueSet variable="maverick-rule">
      <value value="&quot;Rule 1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="truncated-gaussian?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-followers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="zoo">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cutoff-threshold">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-particles">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="he-rule">
      <value value="&quot;Analytically tractable&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="follow-rule">
      <value value="&quot;Rule 1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-mavericks">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="number-of-foliators" first="10" step="10" last="400"/>
    <enumeratedValueSet variable="number-of-climbers">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-clairvoyance">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="zor">
      <value value="6.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="center-turtle?">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2-A" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="1002"/>
    <exitCondition>inertia?</exitCondition>
    <metric>peaks-times-visited</metric>
    <metric>peaks-first-visited</metric>
    <metric>max peaks-first-visited</metric>
    <metric>sig-progress-200</metric>
    <metric>sig-progress-500</metric>
    <metric>sig-progress-1000</metric>
    <metric>sig-progress-2000</metric>
    <metric>total-progress-200</metric>
    <metric>total-progress-500</metric>
    <metric>total-progress-1000</metric>
    <metric>total-progress-2000</metric>
    <metric>count markers</metric>
    <metric>count markers with [by-follower?]</metric>
    <metric>count markers with [by-maverick?]</metric>
    <metric>count markers with [by-follower? and by-maverick?]</metric>
    <metric>count patches</metric>
    <metric>count patches with [significance &gt;= cutoff-threshold]</metric>
    <metric>count patches with [significance &gt;= cutoff-threshold and times-visited &gt; 0]</metric>
    <metric>count markers with [by-follower? and [significance] of patch-here &gt;= cutoff-threshold]</metric>
    <metric>count markers with [by-maverick? and [significance] of patch-here &gt;= cutoff-threshold]</metric>
    <metric>count markers with [by-follower? and by-maverick? and [significance] of patch-here &gt;= cutoff-threshold]</metric>
    <enumeratedValueSet variable="number-of-foliators">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="center-turtle?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maverick-rule">
      <value value="&quot;Rule 1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cutoff-threshold">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="truncated-gaussian?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-followers">
      <value value="100"/>
      <value value="200"/>
      <value value="300"/>
      <value value="400"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-climbers">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="number-of-mavericks" first="0" step="10" last="50"/>
    <enumeratedValueSet variable="number-of-particles">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="he-rule">
      <value value="&quot;Rule 3&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="zor">
      <value value="6.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="zoo">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="p-clairvoyance">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="follow-rule">
      <value value="&quot;Rule 2&quot;"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
1
@#$#@#$#@
